@@ -98,3 +98,6 @@ class TestAsyncDocumentMethod(unittest.IsolatedAsyncioTestCase):
 
         user = await User.find_one_async({"name": "Julius Caesar"})
         self.assertEqual(user.age, 60)
+
+        user = await User.find_one_async({"name": "No Body"})
+        self.assertIsNone(user)
